=== modified file 'ivle/dispatch/request.py'
--- ivle/dispatch/request.py	2009-04-28 06:39:38 +0000
+++ ivle/dispatch/request.py	2009-06-24 08:48:19 +0000
@@ -79,24 +79,6 @@
         location (write)
             String. Response "Location" header value. Used with HTTP redirect
             responses.
-        styles (write)
-            List of strings. Write a list of URLs to CSS files here, and they
-            will be incorporated as <link rel="stylesheet" type="text/css">
-            elements in the head, if write_html_head_foot is True.
-            URLs should be relative to the IVLE root; they will be fixed up
-            to be site-relative.
-        scripts (write)
-            List of strings. Write a list of URLs to JS files here, and they
-            will be incorporated as <script type="text/javascript"> elements
-            in the head, if write_html_head_foot is True.
-            URLs should be relative to the IVLE root; they will be fixed up
-            to be site-relative.
-        scripts_init (write)
-            List of strings. Write a list of JS function names, and they
-            will be added as window.addListener('load', ..., false); calls
-            in the head, if write_html_head_foot is True.
-            This is the propper way to specify functions that need to run at 
-            page load time.
     """
 
     # Special code for an OK response.
@@ -194,9 +176,6 @@
         self.status = Request.HTTP_OK
         self.content_type = None        # Use Apache's default
         self.location = None
-        self.styles = []
-        self.scripts = []
-        self.scripts_init = []
         # In some cases we don't want the template JS (such as the username
         # and public FQDN) in the output HTML. In that case, set this to 0.
         self.write_javascript_settings = True

=== modified file 'ivle/webapp/admin/user.py'
--- ivle/webapp/admin/user.py	2009-05-11 04:21:11 +0000
+++ ivle/webapp/admin/user.py	2009-06-24 08:47:02 +0000
@@ -66,7 +66,7 @@
 
     def populate(self, req, ctx):
         self.plugin_scripts[Plugin] = ['settings.js']
-        req.scripts_init = ['revert_settings']
+        self.scripts_init = ['revert_settings']
 
         ctx['login'] = self.context.login
 

=== modified file 'ivle/webapp/base/xhtml.py'
--- ivle/webapp/base/xhtml.py	2009-04-28 06:39:38 +0000
+++ ivle/webapp/base/xhtml.py	2009-06-24 08:45:48 +0000
@@ -37,8 +37,11 @@
     """
 
     template = 'template.html'
+
     plugin_scripts = {}
     plugin_styles = {}
+    scripts_init = []
+
     allow_overlays = True
     overlay_blacklist = []
 
@@ -64,28 +67,33 @@
         tmpl = loader.load(app_template)
         app = self.filter(tmpl.generate(viewctx), viewctx)
 
+        view_scripts = []
         for plugin in self.plugin_scripts:
             for path in self.plugin_scripts[plugin]:
-                req.scripts.append(media_url(req, plugin, path))
+                view_scripts.append(media_url(req, plugin, path))
 
+        view_styles = []
         for plugin in self.plugin_styles:
             for path in self.plugin_styles[plugin]:
-                req.styles.append(media_url(req, plugin, path))
+                view_styles.append(media_url(req, plugin, path))
 
         # Global template
         ctx = genshi.template.Context()
-        # XXX: Leave this here!! (Before req.styles is read)
-        ctx['overlays'] = self.render_overlays(req) if req.user else []
+
+        overlay_bits = self.render_overlays(req) if req.user else [[]]*4
+        ctx['overlays'] = overlay_bits[0]
 
         ctx['styles'] = [media_url(req, CorePlugin, 'ivle.css')]
-        ctx['styles'] += req.styles
+        ctx['styles'] += view_styles
+        ctx['styles'] += overlay_bits[1]
 
         ctx['scripts'] = [media_url(req, CorePlugin, path) for path in
                            ('util.js', 'json2.js', 'md5.js')]
         ctx['scripts'].append(media_url(req, '+external/jquery', 'jquery.js'))
-        ctx['scripts'] += req.scripts
+        ctx['scripts'] += view_scripts
+        ctx['scripts'] += overlay_bits[2]
 
-        ctx['scripts_init'] = req.scripts_init
+        ctx['scripts_init'] = self.scripts_init + overlay_bits[3]
         ctx['app_template'] = app
         ctx['title_img'] = media_url(req, CorePlugin,
                                      "images/chrome/title.png")
@@ -149,8 +157,11 @@
         scripts_init.
         """
         overlays = []
+        styles = []
+        scripts = []
+        scripts_init = []
         if not self.allow_overlays:
-            return overlays
+            return (overlays, styles, scripts, scripts_init)
 
         for plugin in req.config.plugin_index[OverlayPlugin]:
             for overclass in plugin.overlays:
@@ -160,16 +171,16 @@
                 #TODO: Re-factor this to look nicer
                 for mplugin in overlay.plugin_scripts:
                     for path in overlay.plugin_scripts[mplugin]:
-                        req.scripts.append(media_url(req, mplugin, path))
+                        scripts.append(media_url(req, mplugin, path))
 
                 for mplugin in overlay.plugin_styles:
                     for path in overlay.plugin_styles[mplugin]:
-                        req.styles.append(media_url(req, mplugin, path))
+                        styles.append(media_url(req, mplugin, path))
 
-                req.scripts_init += overlay.plugin_scripts_init
+                scripts_init += overlay.plugin_scripts_init
 
                 overlays.append(overlay.render(req))
-        return overlays
+        return (overlays, styles, scripts, scripts_init)
 
     @classmethod
     def get_error_view(cls, e):

=== modified file 'ivle/webapp/filesystem/browser/__init__.py'
--- ivle/webapp/filesystem/browser/__init__.py	2009-05-26 02:10:08 +0000
+++ ivle/webapp/filesystem/browser/__init__.py	2009-06-24 08:47:02 +0000
@@ -62,7 +62,7 @@
                                        'editor.js',
                                        'specialhome.js',
                                        'codepress/codepress.js']
-        req.scripts_init = ["browser_init"]
+        self.scripts_init = ["browser_init"]
 
         # Start writing data
 

